import 'package:flutter/rendering.dart';
import 'package:leancode_logging/leancode_logging.dart';
import 'package:flutter_bugfender/flutter_bugfender.dart';

/// Bugfender logger
///
/// If [debugMode] set to true, then [logDebug] logs are logged
/// and all other logs are printed to console via `debugPrint`
class Bugfender extends Logger {
  Bugfender(this.appKey, this.debugMode);

  final String appKey;

  /// If set to true, then [logDebug] logs are logged
  /// and all other logs are printed to console via `debugPrint`
  final bool debugMode;

  @override
  void logDebug(String message) {
    if (debugMode == true) {
      FlutterBugfender.log(message);
    }
    if (debugMode == true) {
      debugPrint(message);
    }
  }

  @override
  void logError(String message) {
    FlutterBugfender.error(message);
    if (debugMode == true) {
      debugPrint(message);
    }
  }

  @override
  void logException(dynamic ex, [StackTrace stackTrace]) {
    FlutterBugfender.error(ex.toString() + '\n' + stackTrace.toString());
    if (debugMode == true) {
      debugPrint(ex.toString() + '\n' + stackTrace.toString());
    }
  }

  @override
  void logInfo(String message) {
    FlutterBugfender.log(message);
    if (debugMode == true) {
      debugPrint(message);
    }
  }

  @override
  void logWarning(String message) {
    FlutterBugfender.warn(message);
    if (debugMode == true) {
      debugPrint(message);
    }
  }

  void removeDeviceKey(String key) {
    FlutterBugfender.removeDeviceString(key);
  }

  void setDeviceValue(String key, dynamic value) {
    FlutterBugfender.setDeviceString(key, value);
  }

  Future<void> init() {
    return FlutterBugfender.init(appKey);
  }
}
