import 'package:flutter/rendering.dart';
import 'package:leancode_logging/leancode_logging.dart';

/// Bugfender logger
///
/// If [debugMode] set to true, then [logDebug] logs are logged
/// and all other logs are printed to console via `debugPrint`
class ConsoleLogger extends Logger {
  ConsoleLogger(this.debugMode);

  /// If set to true, then [logDebug] logs are logged
  /// and all other logs are printed to console via `debugPrint`
  final bool debugMode;

  @override
  void logDebug(String message) {
    if (debugMode == true) {
      debugPrint(message);
    }
  }

  @override
  void logError(String message) {
    debugPrint(message);
  }

  @override
  void logException(dynamic ex, [StackTrace stackTrace]) {
    debugPrint(ex.toString() + '\n' + stackTrace.toString());
  }

  @override
  void logInfo(String message) {
    debugPrint(message);
  }

  @override
  void logWarning(String message) {
    debugPrint(message);
  }
}
